==> jc-1.4.0.tar.gz: javax/swing/tree/AbstractLayoutCache__24NodeDimensions.h <==
// public abstract class javax.swing.tree.AbstractLayoutCache$NodeDimensions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b132529ee8250685 javax_swing_tree_AbstractLayoutCache__24NodeDimensions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_tree_AbstractLayoutCache__24NodeDimensions_H_
#define _JC_javax_swing_tree_AbstractLayoutCache__24NodeDimensions_H_

// Forward structure declarations
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_refs	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_refs;
typedef struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_nonrefs	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_nonrefs;
typedef struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$refs	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$refs;
typedef struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$nonrefs	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$nonrefs;
typedef struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object;

typedef const struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vmethods	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vmethods;
typedef const struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtable	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtable;
typedef const struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype;

// Constructors
extern void _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *);

// Virtual methods
extern struct _jc_java_awt_Rectangle$object *_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$getNodeDimensions$12b4497979399f42(_jc_env *, struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *, struct _jc_java_lang_Object$object *, jint, jint, jboolean, struct _jc_java_awt_Rectangle$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$getNodeDimensions$12b4497979399f42;

// Virtual methods structure
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vmethods {
	struct _jc_java_awt_Rectangle$object	*(*getNodeDimensions$12b4497979399f42)(_jc_env *, struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *, struct _jc_java_lang_Object$object *, jint, jint, jboolean, struct _jc_java_awt_Rectangle$object *);
};

// Vtable
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vmethods	javax_swing_tree_AbstractLayoutCache__24NodeDimensions;
};

// Vtype
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype {
	_jc_type			type;
	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$refs {
    _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_refs	javax_swing_tree_AbstractLayoutCache__24NodeDimensions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_nonrefs	javax_swing_tree_AbstractLayoutCache__24NodeDimensions;
};

// Object instance structure
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object {
	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype	*vtype;
	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_tree_AbstractLayoutCache__24NodeDimensions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$class_object;

#endif	/* _JC_javax_swing_tree_AbstractLayoutCache__24NodeDimensions_H_ */

==> jc-1.4.5.tar.gz: javax/swing/tree/AbstractLayoutCache__24NodeDimensions.h <==
// public abstract class javax.swing.tree.AbstractLayoutCache$NodeDimensions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b132529ee8250685 javax_swing_tree_AbstractLayoutCache__24NodeDimensions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_tree_AbstractLayoutCache__24NodeDimensions_H_
#define _JC_javax_swing_tree_AbstractLayoutCache__24NodeDimensions_H_

// Forward structure declarations
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_refs	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_refs;
typedef struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_nonrefs	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_nonrefs;
typedef struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$refs	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$refs;
typedef struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$nonrefs	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$nonrefs;
typedef struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object;

typedef const struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vmethods	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vmethods;
typedef const struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtable	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtable;
typedef const struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype;

// Constructors
extern void _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Rectangle$object *_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method$getNodeDimensions$12b4497979399f42(_jc_env *, struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *, struct _jc_java_lang_Object$object *, jint, jint, jboolean, struct _jc_java_awt_Rectangle$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$method_info$getNodeDimensions$12b4497979399f42;

// Virtual methods structure
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vmethods {
	struct _jc_java_awt_Rectangle$object	*(*getNodeDimensions$12b4497979399f42)(_jc_env *, struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object *, struct _jc_java_lang_Object$object *, jint, jint, jboolean, struct _jc_java_awt_Rectangle$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vmethods	javax_swing_tree_AbstractLayoutCache__24NodeDimensions;
};

// Vtype
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype {
	_jc_type			type;
	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$refs {
    _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_refs	javax_swing_tree_AbstractLayoutCache__24NodeDimensions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$sub_nonrefs	javax_swing_tree_AbstractLayoutCache__24NodeDimensions;
};

// Object instance structure
struct _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$object {
	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype	*vtype;
	_jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$vtype _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_tree_AbstractLayoutCache__24NodeDimensions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_tree_AbstractLayoutCache__24NodeDimensions$class_object;

#endif	/* _JC_javax_swing_tree_AbstractLayoutCache__24NodeDimensions_H_ */
